@@ -80,16 +80,6 @@ want to know who called C<die()>.
 
     $SIG{__DIE__} = sub { $log->trace(emergency => @_) };
 
-By default the backtrace is logged as level C<debug>.
-
-    # would log with the level debug
-    $log->trace('who called who');
-
-If you want to log with another level then you can pass the level
-as first argument:
-
-    $log->trace(info => $message);
-
 =item B<dump()>
 
 If you want to dump something then you can use C<dump()>.
@@ -97,11 +87,6 @@ The default level is C<debug>.
 
     my %hash = (foo => 1, bar => 2);
 
-    $log->dump(\%hash);
-
-If you want to log with another level then you can pass the level
-as first argument:
-
     $log->dump($level => \%hash);
 
 =item B<die()>
@@ -109,11 +94,6 @@ as first argument:
 This method logs the message to the output and then call C<Carp::croak()>
 with the level C<emergency> by default.
 
-    $log->die('an emergency error here');
-
-If you want to log with another level, then you can pass the level
-as first argument:
-
     $log->die(fatal => 'an emergency error here');
 
 =item B<log()>
@@ -123,15 +103,16 @@ first argument:
 
     $log->log(info => 'an info message');
 
-Is the same like
+=item B<tagged()>
 
-    $log->info('an info message');
+With this method it's possible to add some tags to a message:
 
-and
-
-    $log->log('an info message');
-
-If you log without a level then the default level is C<info>.
+    $log->tagged(
+        level    => "debug",
+        message  => "log this message",
+        karma    => 42,
+        tags     => "security,foo",
+    );
 
 =back
 
@@ -156,7 +137,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -170,7 +151,7 @@ use warnings;
 use Carp;
 use Data::Dumper;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 my %LEVELS_BY_ROUTINE = (
     debug     => 'DEBUG',
@@ -235,6 +216,23 @@ foreach my $routine (keys %LEVELS_BY_ROUTINE) {
     } # end "no strict 'refs'" block
 }
 
+sub tagged {
+    my $self  = shift;
+    my $tags  = ref($_[0]) eq "HASH" ? shift : {@_};
+    my $level = $tags->{level};
+
+    if (!defined $level) {
+        $level = $tags->{level} = "info";
+    }
+
+    if (!exists $LEVELS_BY_ROUTINE{$level}) {
+        $level = $tags->{level} = "info";
+    }
+
+    local $Log::Handler::CALLER_LEVEL = 1;
+    return $self->$level($tags);
+}
+
 sub log {
     my $self  = shift;
     my $level = @_ > 1 ? lc(shift) : 'info';
