@@ -186,9 +186,22 @@ You can pass your own arguments - and overwrite it - with
 
     dbi_params => { PrintError => 1, AutoCommit => 0 }
 
+=item B<use_ping>
+
+By default a short statement is executed to check if the connection
+is alive because ping() doesn't work with all DBD properly.
+
+    select 1
+
+or for oracle
+
+    select 1 from dual
+
+If you want to use the ping() function instead set C<use_ping> to 1.
+
 =item B<debug>
 
-With this option it's possible to enable debugging. The informations can be
+With this option it's possible to enable debugging. The information can be
 intercepted with C<$SIG{__WARN__}>.
 
 =back
@@ -224,6 +237,10 @@ Connect to the database.
 
 Disconnect from the database.
 
+=head2 validate()
+
+Validate a configuration.
+
 =head2 reload()
 
 Reload with a new configuration.
@@ -266,11 +283,11 @@ package Log::Handler::Output::DBI;
 
 use strict;
 use warnings;
-use Carp;
 use DBI;
-use Params::Validate;
+use Carp;
+use Params::Validate qw();
 
-our $VERSION = "0.08";
+our $VERSION = "0.11";
 our $ERRSTR  = "";
 
 sub new {
@@ -321,15 +338,20 @@ sub connect {
     my $self = shift;
 
     if ($self->{persistent} && $self->{dbh}) {
-        eval { $self->{dbh}->do("select 1") or die DBI->errstr };
-        return 1 unless $@;
+        if ($self->{use_ping}) {
+            if ($self->{dbh}->ping) {
+                return 1;
+            }
+        } else {
+            eval { $self->{dbh}->do($self->{pingstmt}) or die DBI->errstr };
+            return 1 unless $@;
+        }
     }
 
     if ($self->{debug}) {
         warn "Connect to the database: $self->{cstr}->[0] ...";
     }
 
-
     my $dbh = DBI->connect(@{$self->{cstr}})
         or return $self->_raise_error("DBI connect error: ".DBI->errstr);
 
@@ -366,7 +388,7 @@ sub disconnect {
     return 1;
 }
 
-sub reload {
+sub validate {
     my $self = shift;
     my $opts = ();
 
@@ -375,7 +397,18 @@ sub reload {
     if ($@) {
         return $self->_raise_error($@);
     }
-    
+
+    return $opts;
+}
+
+sub reload {
+    my $self = shift;
+    my $opts = $self->validate(@_);
+
+    if (!$opts) {
+        return undef;
+    }
+
     $self->disconnect;
 
     foreach my $key (keys %$opts) {
@@ -385,7 +418,9 @@ sub reload {
     return 1;
 }
 
-sub errstr { $ERRSTR }
+sub errstr {
+    return $ERRSTR;
+}
 
 #
 # private stuff
@@ -452,6 +487,11 @@ sub _validate {
             type => Params::Validate::HASHREF,
             default => { PrintError => 0, AutoCommit => 1 },
         },
+        use_ping => {
+            type => Params::Validate::SCALAR,
+            regex => qr/^[01]\z/,
+            default => 0,
+        },
         debug => {
             type => Params::Validate::SCALAR,
             regex => qr/^[01]\z/,
@@ -526,6 +566,12 @@ sub _validate {
         $options{statement} .= ")";
     }
 
+    if ($options{driver} =~ /oracle/i) {
+        $options{pingstmt} = "select 1 from dual";
+    } else {
+        $options{pingstmt} = "select 1";
+    }
+
     return \%options;
 }
 
